==> cost-main-rpc-1.4.5-sources.jar: com/chinayanghe/tpm/rpc/rpc/ActivitiByFormRpcService.java <==
package com.chinayanghe.tpm.rpc.rpc;

import com.chinayanghe.tpm.rpc.vo.ActivityBaseInfoVo;
import com.chinayanghe.tpm.rpc.vo.ManageInfoVo;
import com.chinayanghe.tpm.rpc.vo.financeInfo.FinanceInfoApplyVo;

/**
 * 流程发起表单存储接口
 * @ClassName: com.chinayanghe.tpm.cost.rpc.swagger
 * Created by OmarZhang on 2017/7/7 14:47.
 */
public interface ActivitiByFormRpcService {

    /***
     * 根据活动单号获取活动基础信息
     * @param formNo
     * @return
     */
    ActivityBaseInfoVo findActivityBaseInfoByCode(String formNo);
    
    /**
     * 判断专卖店支持是否为装修支持
     * @param formNo 单号
     * @return  true-是  false-不是
     */
    Boolean isExclusiveOrnament(String formNo);

    /**
     * 根据表单编号获取表单管理信息
     * @param formNo 表单编号
     */
    ManageInfoVo findManageInfoVoByFormNo(String formNo);

    /**
     * 判断是否制式合同
     * @param formNo 单号
     * @return  true-是  false-不是
     */
    Boolean isPactJudge(String formNo);
    
    /**
     * 判断是否为电商部
     * @param positionCode 岗位编号
     * @return  true-是  false-不是
     */
    Boolean isNetMarketing(String positionCode);
    
    /**
     * 判断是否为市场部
     * @param positionCode 岗位编号
     * @return  true-是  false-不是
     */
    Boolean isMarketing(String positionCode);

    /***
     * 流程驳回
     * @param formNo  表单号
     * @param formType 表单类型 com.chinayanghe.tpm.rpc.constants.FormTypeEnum
     * @param activitiId 流程ID
     * @param userId 驳回人
     * @param activitiCode com.chinayanghe.tpm.rpc.constants.ActivityTypeEnum
     */
    BizResponseJson reject(String activitiCode,String formNo,String formType,String activitiId,String userId);
    
    /**
     * 申请金额和审批金额的处理
     * 当审批最后一个节点审批前，把申请金额更新到审批金额中，当在最后一个节点被驳回的时候，要把审批金额清0
     * @param formNo 单号
     * @param type 类型 1-申请单操作  2-核报审批   3-核报复核
     * @param flag  true -把申请金额更新到审批金额中，false-把审批金额清0
     */
    Boolean  updateApplyInfoAmt(String formNo,int type,boolean flag);
    
    /**
     * 判断洋河或双沟
     * @param formNo 单号
     * @return  1-洋河  2-双沟  3-洋河双沟 
     */
    int getWineBigType(String formNo);
    
    /**
     * 判断是否为葡萄酒事业部
     * @param positionCode 岗位编号
     * @return  true-是  false-不是
     */
    Boolean isWineDivision(String positionCode);

    /***
     * 表单中断
     * 流程在稽查部节点击终止后，发起人将部可以再发次改表单。申请单，预算释放回去。
     * 登记不返回申请单余额、核报单不返回给登记单余额，核报单不释放预算，永久冻结
     * @param activitiCode 活动单号
     * @param formNo  表单号
     * @param formType 表单类型
     * @param activitiId 流程节点ID
     * @param userId  操作人
     * @return
     */
    BizResponseJson  formInterrupt(String activitiCode,String formNo,String formType,String activitiId,String userId);

    /***
     * 根据活动单号获取申请单财务信息
     * @param formNo
     * @return
     */
    FinanceInfoApplyVo findFinanceInfoApplyByFormNo(String formNo);
    
    /**
     * 判断个性化奖卡延期时间 是否超过180天
     * @param formNo 单号
     * @return  true-是  false-不是
     */
    Boolean isDelay180(String formNo);
    
    /**
     * 买赠促销判断是否有个性化奖卡金额
     * @param formNo 单号
     * @return  true-是  false-不是
     */
    Boolean isPersonalAmount(String formNo);
    
    /**
     * 根据促销类型判断流程走向：
     * 如果促销类型为奖卡买赠（常规）true
     * 如果促销类型为奖卡买赠（面上）false
     * @param formNo 单号
     */
    Boolean isPromotionType(String formNo);
    
    /**
     * 根据终端渠道类型判断流程走向：
     * 如果渠道类型为团购  true
     * 如果为其他 false
     * @param formNo 单号
     */
    Boolean isGroupChannel(String formNo);

    Boolean channelLaborAuditByVipDept(String formNo);
}

==> cost-main-rpc-1.5.1-sources.jar: com/chinayanghe/tpm/rpc/rpc/ActivitiByFormRpcService.java <==
package com.chinayanghe.tpm.rpc.rpc;

import com.chinayanghe.tpm.rpc.vo.ActivityBaseInfoVo;
import com.chinayanghe.tpm.rpc.vo.ManageInfoVo;
import com.chinayanghe.tpm.rpc.vo.budget.BudgetVo;
import com.chinayanghe.tpm.rpc.vo.financeInfo.FinanceInfoApplyVo;

/**
 * 流程发起表单存储接口
 * @ClassName: com.chinayanghe.tpm.cost.rpc.swagger
 * Created by OmarZhang on 2017/7/7 14:47.
 */
public interface ActivitiByFormRpcService {

    /***
     * 根据活动单号获取活动基础信息
     * @param formNo
     * @return
     */
    ActivityBaseInfoVo findActivityBaseInfoByCode(String formNo);
    
    /**
     * 判断专卖店支持是否为装修支持
     * @param formNo 单号
     * @return  true-是  false-不是
     */
    Boolean isExclusiveOrnament(String formNo);

    /**
     * 根据表单编号获取表单管理信息
     * @param formNo 表单编号
     */
    ManageInfoVo findManageInfoVoByFormNo(String formNo);

    /**
     * 判断是否制式合同
     * @param formNo 单号
     * @return  true-是  false-不是
     */
    Boolean isPactJudge(String formNo);
    
    /**
     * 判断是否为电商部
     * @param positionCode 岗位编号
     * @return  true-是  false-不是
     */
    Boolean isNetMarketing(String positionCode);
    
    /**
     * 判断是否为市场部
     * @param positionCode 岗位编号
     * @return  true-是  false-不是
     */
    Boolean isMarketing(String positionCode);

    /***
     * 流程驳回
     * @param formNo  表单号
     * @param formType 表单类型 com.chinayanghe.tpm.rpc.constants.FormTypeEnum
     * @param activitiId 流程ID
     * @param userId 驳回人
     * @param activitiCode com.chinayanghe.tpm.rpc.constants.ActivityTypeEnum
     */
    BizResponseJson reject(String activitiCode,String formNo,String formType,String activitiId,String userId);
    
    /**
     * 申请金额和审批金额的处理
     * 当审批最后一个节点审批前，把申请金额更新到审批金额中，当在最后一个节点被驳回的时候，要把审批金额清0
     * @param formNo 单号
     * @param type 类型 1-申请单操作  2-核报审批   3-核报复核
     * @param flag  true -把申请金额更新到审批金额中，false-把审批金额清0
     */
    Boolean  updateApplyInfoAmt(String formNo,int type,boolean flag);
    
    /**
     * 判断洋河或双沟
     * @param formNo 单号
     * @return  1-洋河  2-双沟  3-洋河双沟 
     */
    int getWineBigType(String formNo);
    
    /**
     * 判断是否为葡萄酒事业部
     * @param positionCode 岗位编号
     * @return  true-是  false-不是
     */
    Boolean isWineDivision(String positionCode);

    /***
     * 表单中断
     * 流程在稽查部节点击终止后，发起人将部可以再发次改表单。申请单，预算释放回去。
     * 登记不返回申请单余额、核报单不返回给登记单余额，核报单不释放预算，永久冻结
     * @param activitiCode 活动单号
     * @param formNo  表单号
     * @param formType 表单类型
     * @param activitiId 流程节点ID
     * @param userId  操作人
     * @return
     */
    BizResponseJson  formInterrupt(String activitiCode,String formNo,String formType,String activitiId,String userId);

    /***
     * 根据活动单号获取申请单财务信息
     * @param formNo
     * @return
     */
    FinanceInfoApplyVo findFinanceInfoApplyByFormNo(String formNo);
    
    /**
     * 判断个性化奖卡延期时间 是否超过180天
     * @param formNo 单号
     * @return  true-是  false-不是
     */
    Boolean isDelay180(String formNo);
    
    /**
     * 买赠促销判断是否有个性化奖卡金额
     * @param formNo 单号
     * @return  true-是  false-不是
     */
    Boolean isPersonalAmount(String formNo);
    
    /**
     * 根据促销类型判断流程走向：
     * 如果促销类型为奖卡买赠（常规）true
     * 如果促销类型为奖卡买赠（面上）false
     * @param formNo 单号
     */
    Boolean isPromotionType(String formNo);
    
    /**
     * 根据终端渠道类型判断流程走向：
     * 如果渠道类型为团购  true
     * 如果为其他 false
     * @param formNo 单号
     */
    Boolean isGroupChannel(String formNo);

    Boolean channelLaborAuditByVipDept(String formNo);


    /**
     * 预算转移流程条件选择
     * @param formNo
     * @return
     */
    BudgetVo budgetTransfer(String formNo);
    /***
     * 预算转移流程驳回
     * @param formNo  表单号
     * @param formType 表单类型 com.chinayanghe.tpm.rpc.constants.FormTypeEnum
     * @param activitiId 流程ID
     * @param userId 驳回人
     * @param activitiCode com.chinayanghe.tpm.rpc.constants.ActivityTypeEnum
     */
    BizResponseJson rejectBudget(String activitiCode,String formNo,String formType,String activitiId,String userId);

}
